package org.openlp.android.fragments;

import android.content.Context;
import android.os.Bundle;
import android.util.Log;
import android.view.*;
import android.widget.*;
import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;
import org.openlp.android.R;
import org.openlp.android.api.Api;
import org.openlp.android.common.JsonHelpers;
import org.openlp.android.common.OpenLPFragment;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;


public class ServiceListFragment extends OpenLPFragment {

    private final String LOG_TAG = ServiceListFragment.class.getName();
    private boolean isLongClicked = false;

    public ServiceListFragment() {
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
        context = getActivity();
        // create ContextThemeWrapper from the original Activity Context with the custom theme
        final Context contextThemeWrapper = new ContextThemeWrapper(getActivity(), R.style.OpenLPFullScreen);
        // clone the inflater using the ContextThemeWrapper
        inflater.cloneInContext(contextThemeWrapper);

        return super.onCreateView(inflater, container, savedInstanceState);
    }

    @Override
    public void onActivityCreated(Bundle savedInstanceState) {
        super.onActivityCreated(savedInstanceState);

        AdapterView.OnItemLongClickListener listener = new AdapterView.OnItemLongClickListener() {
            @Override
            public boolean onItemLongClick(AdapterView<?> arg0, View arg1, int position, long id) {
                Toast.makeText(getActivity().getBaseContext(), "Long Clicked ", Toast.LENGTH_SHORT).show();
                isLongClicked = true;
                return false;
            }
        };
        getListView().setOnItemLongClickListener(listener);
    }

    @Override
    public void populateDisplay(String json) {
        Log.i(LOG_TAG, "populate_display - entry");
        List<HashMap<String, String>> aList = new ArrayList<HashMap<String, String>>();
        try {
            JSONArray items = new JSONObject(json).getJSONObject("results").getJSONArray("items");

            for (int i = 0; i < items.length(); ++i) {
                JSONObject item = items.getJSONObject(i);

                HashMap<String, String> hm = new HashMap<String, String>();
                if (item.getString("plugin").equals("songs")){
                    hm.put("icon", Integer.toString(R.drawable.icon_songs));
                } else if(item.getString("plugin").equals("bibles")) {
                    hm.put("icon", Integer.toString(R.drawable.icon_bibles));
                } else if(item.getString("plugin").equals("media")) {
                    hm.put("icon", Integer.toString(R.drawable.icon_multimedia));
                } else if(item.getString("plugin").equals("presentations")) {
                    hm.put("icon", Integer.toString(R.drawable.icon_presentation));
                } else if(item.getString("plugin").equals("images")) {
                    hm.put("icon", Integer.toString(R.drawable.icon_images));
                } else{
                    hm.put("icon", Integer.toString(R.drawable.icon_custom));
                }

                hm.put("title", item.getString("title"));
                aList.add(hm);
            }
        } catch (JSONException e) {
            e.printStackTrace();
        }
        // Keys used in Hashmap
        String[] from = {"icon", "title"};

        // Ids of views in service_list_fragment                                            s
        int[] to = {R.id.icon, R.id.title};

        // Instantiating an adapter to store each items
        ListAdapter adapter = new SimpleAdapter(getActivity().getBaseContext(), aList,
                R.layout.service_list_fragment, from, to);
        setListAdapter(adapter);
        Log.i(LOG_TAG, "populate_display - exit");
    }

    @Override
    public void onResume() {
        super.onResume();
        Log.d(LOG_TAG, "Resuming...");
        triggerRequest(Api.SERVICE_LIST);
        Log.d(LOG_TAG, "Resumed...");
    }

    private void triggerRequest(String url){
        ExecuteHttpRequestTask task = new ExecuteHttpRequestTask();
        task.execute(new String[]{url});
    }

    public void itemClicked(int position){
        if (!isLongClicked) {
            try {
                String request = JsonHelpers.createRequestJSON("id", Integer.toString(position));
                triggerRequest(String.format("%s%s", Api.SERVICE_SET, request));
                String message = String.format("Setting list data. apiBase(%s), position(%s)",
                        Api.SERVICE_SET, position);
                Log.d(LOG_TAG, message);
                Toast.makeText(getActivity().getBaseContext(), "Service Item selected", Toast.LENGTH_SHORT).show();
            } catch (JsonHelpers.JSONHandlerException e) {
                e.printStackTrace();
                Toast.makeText(getActivity().getBaseContext(), "Request Failed", Toast.LENGTH_SHORT).show();
            }
        }
        triggerRequest(Api.SERVICE_LIST);
        isLongClicked = false;
    };

}