/******************************************************************************
 * OpenLP - Open Source Lyrics Projection                                      *
 * --------------------------------------------------------------------------- *
 * Copyright (c) 2011-2013 Raoul Snyman                                        *
 * Portions copyright (c) 2011-2013 Tim Bentley, Johan Mynhardt, Samuel        *
 * Sjöbergsson                                                                 *
 * --------------------------------------------------------------------------- *
 * This program is free software; you can redistribute it and/or modify it     *
 * under the terms of the GNU General Public License as published by the Free  *
 * Software Foundation; version 2 of the License.                              *
 *                                                                             *
 * This program is distributed in the hope that it will be useful, but WITHOUT *
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or       *
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for    *
 * more details.                                                               *
 *                                                                             *
 * You should have received a copy of the GNU General Public License along     *
 * with this program; if not, write to the Free Software Foundation, Inc., 59  *
 * Temple Place, Suite 330, Boston, MA 02111-1307 USA                          *
 *******************************************************************************/
package org.openlp.android.preference;

import android.os.Bundle;
import android.preference.*;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import org.openlp.android.R;

/**
 * Credits: http://www.kaloer.com/android-preferences
 * http://androidpartaker.wordpress.com/2010/07/11/android-preferences/
 */
public class Preferences extends PreferenceFragment {

    private final String LOG_TAG = Preferences.class.getName();

    public Preferences() {
        // Empty constructor required for fragment subclasses
    }

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        Log.d(LOG_TAG, "Launching preferences");
        buildPreferences();
    }

    @Override
    public View onCreateView(LayoutInflater inflater, ViewGroup container, Bundle savedInstanceState) {
        View view = super.onCreateView(inflater, container, savedInstanceState);
        int imageId = getResources().getIdentifier("openlp_logo_android","drawable", getActivity().getPackageName());
        view.setBackgroundResource(imageId);

        return view;
    }

    private void buildPreferences() {
        if (getPreferenceScreen() != null) getPreferenceScreen().removeAll();

        getPreferenceManager().setSharedPreferencesName(getString(R.string.keySharedPreferences));

        addPreferencesFromResource(R.xml.preferences);
    }

    @Override
    public void onDestroy() {
        super.onDestroy();
        Log.d(LOG_TAG, "Destroying preferences");
    }

    @Override
    public void onResume() {
        super.onResume();
        Log.i(LOG_TAG, "Resuming Preferences...");
        buildPreferences();
    }
}
